@@ -115,7 +115,8 @@ def extract_reprompt(df_pr_phone):
                         prompt_arrays.append(new_reprompt_row)
 
     df_prompt = pd.DataFrame(prompt_arrays)
-    df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Question_Set_Prompt_Local_Time', 'UTC_Offset']
+    if df_prompt.shape[0] > 0:
+        df_prompt.columns = ['Prompt_Type', 'Study_Mode', 'Initial_Prompt_Local_Time', 'Answer_Status', 'Question_Set_Prompt_Local_Time', 'UTC_Offset']
 
     return df_prompt
 
@@ -136,6 +137,9 @@ def clean_response_files(intermediate_participant_path, date_in_study, participa
 
     # read and filter prompt type
     df_raw = pd.read_csv(csv_path[0])
+    if df_raw.shape[0] == 0:
+        print("Empty prompt response file : " + csv_path[0])
+        sys.exit()
     df_raw = df_raw[columns_list]
 
     if "Reprompt2_Prompt_UnixTime " in df_raw.columns:
